#
# spec file for package spack
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{?nil}
%if "%{flavor}" == "doc"
%bcond_without doc
%endif

%if %{with doc} && (0%{?sle_version} > 0) && (150200 >= 0%{?sle_version})
ExclusiveArch:  do_not_build
%endif

%define spack_dir  %_prefix/lib/spack/
%define spack_group spack
# These packages are found and can be used by spack, /etc/spack/packages-yaml
# needs to be updated when one of these packages is updated or uninstalled.
# Distinguish between packages we recommend and packages which
%define spack_trigger_recommended autoconf bash bison bzip2 libzip-devel cmake-full ccache cpio diffutils findutils flex gcc gcc-c++ gcc-fortran git-lfs make m4 ncurses-devel libtool openssl-devel perl-base pkgconf pkg-config python3-base tar info xz xz-devel
# packages recognized by spack, but not recommended
%define spack_trigger_packages ghostscript go fish fzf hugo java-11-openjdk-devel java-14-openjdk-devel java-15-openjdk-devel java-16-openjdk-devel java-1_8_0-openjdk-devel ruby openmpi1-devel openmpi2-devel openmpi3-devel openmpi4-devel openmpi1-gnu-hpc-devel openmpi2-gnu-hpc-devel openmpi3-gnu-hpc-devel openmpi4-gnu-hpc-devel mvapich2-devel mpich-devel gcc7 gcc8 gcc9 gcc10 gcc11 gcc7-c++ gcc8-c++ gcc9-c++ gcc10-c++ gcc11-c++ gcc7-fortran gcc8-fortran gcc9-fortran gcc10-fortran gcc11-fortran
# non oss packages
%define spack_trigger_external cuda-nvcc
Name:           spack
Version:        0.17.1
Release:        150400.10.4
Summary:        Package manager for HPC systems
License:        Apache-2.0 AND MIT AND Python-2.0 AND BSD-3-Clause
URL:            https://spack.io
Source0:        https://github.com/spack/spack/archive/v%{version}.tar.gz#/spack-%{version}.tar.gz
Source1:        README.SUSE
Source2:        spack-rpmlintrc
Source3:        run-find-external.sh.in
Source4:        https://en.opensuse.org/index.php?title=Spack&action=raw&ref=157522#/README-oo-wiki
# Source5 is from https://docs.python.org/3/objects.inv, but has permanent changes so using a static version
Source5:        objects.inv
Patch1:         fix-tumbleweed-naming.patch
Patch2:         Adapt-shell-scripts-that-set-up-the-environment-for-different-shells.patch
Patch4:         added-target-and-os-calls-to-output-of-spack-spec-co.patch
Patch5:         Make-spack-paths-compliant-to-distro-installation.patch
Patch6:         Fix-error-during-documentation-build-due-to-recursive-module-inclusion.patch
Patch7:         Fix-Spinx-configuration-to-avoid-throwing-errors.patch
Patch8:         Set-modules-default-to-lmod.patch
Patch9:         Add-support-for-container-building-using-a-SLE-base-container.patch
%if %{without doc}
BuildRequires:  fdupes
BuildRequires:  lua-lmod
BuildRequires:  polkit
BuildRequires:  python3-urllib3
BuildRequires:  sudo
BuildRequires:  sysuser-tools
Requires:       %{name}-recipes = %{version}
Requires:       bzip2
Requires:       coreutils
Requires:       curl
Requires:       gcc-c++
Requires:       gcc-fortran
Requires:       gpg2
Requires:       libbz2-devel
Requires:       lua-lmod
Requires:       make
Requires:       patch
Requires:       polkit
Requires:       python3-clingo
Requires:       sudo
Requires:       tar
Requires:       xz
Recommends:     %spack_trigger_recommended
%else
BuildRequires:  git
BuildRequires:  makeinfo
# Hardcode this - there is no python2 version of this around any more.
BuildRequires:  python3-Sphinx >= 3.4
BuildRequires:  python3-sphinxcontrib-programoutput
BuildRequires:  spack
# html
BuildRequires:  graphviz
# info
BuildRequires:  graphviz-gnome
## pdf
# BuildRequires:  python3-Sphinx-latex
Requires:       spack
%endif
BuildArch:      noarch
%if  0%{?sle_version} <= 120500 && !0%{?is_opensuse}
%define __python3 python3
%endif

%description
Spack is a configurable Python-based HPC package manager, automating
the installation and fine-tuning of simulations and libraries.
It operates on a wide variety of HPC platforms and enables users
to build many code configurations. Software installed by Spack
runs correctly regardless of environment, and file management
is streamlined. Spack can install many variants of the same build
using different compilers, options, and MPI implementations.

This package provides a module file that must be loaded to use spack.

%package recipes
Summary:        Spack built-in package recipes
Requires:       %{name} = %version

%description recipes
Spack is a configurable Python-based HPC package manager, automating
the installation and fine-tuning of simulations and libraries.
It operates on a wide variety of HPC platforms and enables users
to build many code configurations. Software installed by Spack
runs correctly regardless of environment, and file management
is streamlined. Spack can install many variants of the same build
using different compilers, options, and MPI implementations.

This package contains the built-in package recipes.

%package man
Summary:        Man Page for Spack - Package manager for HPC systems
Requires:       man

%description man
Spack is a configurable Python-based HPC package manager, automating
the installation and fine-tuning of simulations and libraries.
It operates on a wide variety of HPC platforms and enables users
to build many code configurations. Software installed by Spack
runs correctly regardless of environment, and file management
is streamlined. Spack can install many variants of the same build
using different compilers, options, and MPI implementations.

This package contains the man page.

%package info
Summary:        Info Page for Spack - Package manager for HPC systems
Requires:       info

%description info
Spack is a configurable Python-based HPC package manager, automating
the installation and fine-tuning of simulations and libraries.
It operates on a wide variety of HPC platforms and enables users
to build many code configurations. Software installed by Spack
runs correctly regardless of environment, and file management
is streamlined. Spack can install many variants of the same build
using different compilers, options, and MPI implementations.

This package contains the info page.

%prep
%setup -q
%autopatch -p1
%if %{without doc}

# set SPACK_ROOT
for i in share/spack/setup-env.*; do
    sed -i -e "s;@@_prefix@@;%_prefix;g" $i
done
%else
cp %{S:5} lib/spack/docs/
%endif

for file in $(find . -type f); do
    sed -e 's@$spack/opt@/opt@g' \
	-e 's@$spack/share/spack/modules@/opt/spack/modules@g' \
	-e 's@$spack/share/spack/lmod@/opt/spack/modules@g' \
	-e 's@$spack/var@/var/lib@g' \
	-i $file
done

%build
# Nothing to build
%if %{with doc}
mkdir -p ${HOME}/.spack
cat > ${HOME}/.spack/config.yaml <<EOF
config:
  install_tree:
    root: /tmp/spack
    projections:
      all: "${ARCHITECTURE}/${COMPILERNAME}-${COMPILERVER}/${PACKAGE}-${VERSION}-${HASH}"
EOF
# Don't really run spack when building documentation!
tmpdir=$(mktemp -d %{_sourcedir}/tmpd-XXXXXXXXX)
echo -e '#! /bin/sh
args=${1+"$@"}
while [ -n "$1" ]; do
  case $1 in
    --*) shift ;;
    graph|spec) exit 0 ;;
    *) exec /usr/bin/spack ${args} ;;
  esac;
done
exit 0' > $tmpdir/spack
chmod 0755 $tmpdir/spack
PATH=$tmpdir:${PATH}
export PATH
mkdir -p /tmp/spack
cd lib/spack/docs
# fix Makefile of sphinx and ignore warnings due to offline build
sed -i 's/\(^SPHINXOPTS\).*/\1 = --keep-going /' Makefile
# Causes issues building texinfo as a suitable image cannot be found
grep -rl ":target:" | xargs sed  -i -e "/:target:/s/^/#/" -e "/figure::/s/^/#/"
# Fix path to var - we install this to the 'real' /var
grep -rl "\$SPACK_ROOT/var" | xargs sed -i -e "s@\(.*\)\$SPACK_ROOT/var\(/spack.*\)@\1/var/lib\2@g"
# spack cannot run without knowing at least the compiler, so we inject
# a dummy one
mkdir -p ${HOME}/.spack/linux/
cat >  ${HOME}/.spack/linux/compilers.yaml <<EOF
compilers:
- compiler:
    spec: gcc@7.5.0
    paths:
      cc: /usr/bin/gcc
      cxx: /usr/bin/g++
      f77: /usr/bin/gfortran
      fc: /usr/bin/gfortran
    flags: {}
    operating_system: SUSE
    target: x86_64
    modules: []
    environment:
      unset: []
    extra_rpaths: []
EOF
source /usr/share/spack/setup-env.sh
make man info || { cat /tmp/sphinx-err-*.log; exit 1; } #text dirhtml
rm -rf $tmpdir
gzip _build/texinfo/Spack.info _build/man/spack.1
%endif

%install
# combine READMEs
cat %{S:4} >> %{S:1}
%if %{without doc}
cp %{S:1} .
# Fix some rpmlint warnings
## Remove files not required to run spack
rm -rf lib/spack/spack/test
rm -rf share/spack/qa
rm -rf share/spack/logo
rm -rf var/spack/repos/builtin.mock  var/spack/gpg.mock var/spack/mock_configs
rm -rf lib/spack/external/ruamel/yaml/.ruamel
find . -type f -name .gitignore -delete
find . -type f -name .nojekyll -delete
# Fix _spack_root link
rm -f lib/spack/docs/_spack_root
ln -sf ../.. lib/spack/docs/_spack_root
# Do not ship Docker and container building for now - needs fixing
rm -rf share/spack/{templates/container}
rm -rf share/spack/docker/{centos,ubuntu}*.dockerfile
# Do not ship AWS specifics
rm -f share/spack/setup-tutorial-env.sh
# Fix rpmlint warnings
## No need for the standalone scripts
rm -f lib/spack/external/macholib/macho_*.py
## Fix shebangs
sed -i 's@#!/bin/env sh@#!/bin/bash@' var/spack/repos/builtin/packages/beast-tracer/tracer
sed -i 's@#! /usr/bin/env bash@ #!/bin/bash@' share/spack/docker/entrypoint.bash
sed -i 's@#!/usr/bin/env bash@#!/bin/bash@' share/spack/docker/package-index/split.sh

mkdir -p %{buildroot}%{spack_dir}
mkdir -p %{buildroot}%{spack_dir}/opt
mkdir -p %{buildroot}%{_datarootdir}/spack/lib/spack
mkdir -p %{buildroot}%{_datarootdir}/spack/modules
mkdir -p %{buildroot}%{_localstatedir}/lib/spack
mkdir -p %{buildroot}%{_localstatedir}/lib/spack/junit-report
mkdir -p %{buildroot}%{_localstatedir}/cache/spack
mkdir -p %{buildroot}%{_sysconfdir}/skel/.spack/
mkdir -p %{buildroot}/%{_bindir}
# Link avoids having to fix paths
ln -sf %{buildroot}/%{_localstatedir}/cache/spack %{buildroot}%{_localstatedir}/lib/spack/cache

# Copy files to corresponding paths
cp -r etc %{buildroot}%{_prefix}
cp -r lib/spack/{env,external,llnl,spack} %{buildroot}%{spack_dir}
cp -r share/spack/* %{buildroot}%{_datarootdir}/spack
cp -r var/spack/* %{buildroot}%{_localstatedir}/lib/spack
cp -r bin/sbang %{buildroot}/%{_bindir}
cp -r bin/spack* %{buildroot}%{_bindir}/
cp etc/spack/defaults/config.yaml %{buildroot}%{_sysconfdir}/skel/.spack/
install -m 755 %{S:3} %{buildroot}/%{spack_dir}/run-find-external.sh
sed -i -e 's#@@_sysconfdir@@#%{_sysconfdir}#' %{buildroot}/%{spack_dir}/run-find-external.sh

# Make spack only to write to home dir of user, if run as user
sed -i 's@\(\sroot:\) /opt/spack@\1 ~/spack/packages@' %{buildroot}%{_sysconfdir}/skel/.spack/config.yaml
sed -i 's@\(\ssource_cache:\).*@\1 /var/tmp/$user/spack-cache@' %{buildroot}%{_sysconfdir}/skel/.spack/config.yaml
cat >>  %{buildroot}%{_sysconfdir}/skel/.spack/config.yaml <<EOF
  binary_index_root: ~/.spack/indices
EOF

cat >> %{buildroot}%{_sysconfdir}/skel/.spack/modules.yaml <<EOF
modules:
  default:
    roots:
      tcl: ~/spack/modules
      lmod: ~/spack/modules
EOF

# compile python files for python3
# %%{buildroot}%%{spack_dir}/spack
%py3_compile .

# make shell scripts executeable
find %{buildroot}%{_localstatedir}/lib/spack/ -type f -name \*.sh  -exec chmod 755 {} \;

# Create /etc/spack/compilers.yaml
mkdir -p %{buildroot}%{spack_dir}/etc/spack/
cat >  %{buildroot}%{spack_dir}/etc/spack/compilers.yaml <<EOF
compilers:
- compiler:
    spec: gcc@GCC_FULL_VERSION
    paths:
      cc: /usr/bin/gcc-GCC_VERSION
      cxx: /usr/bin/g++-GCC_VERSION
      f77: /usr/bin/gfortran-GCC_VERSION
      fc: /usr/bin/gfortran-GCC_VERSION
    flags: {}
    operating_system: SUSE_VERSION
    target: HOSTTYPE
    modules: []
    environment:
      unset: []
    extra_rpaths: []
EOF

# Create /etc/profile.d/spack.sh
# This file properly sets MODULEPATH so lua-lmod can find the modules created by spack
mkdir -p %{buildroot}/%{_sysconfdir}/profile.d
cat > %{buildroot}/%{_sysconfdir}/profile.d/spack.sh <<EOF
source /etc/os-release
if [ "\${ID}" == "opensuse-tumbleweed" ] ; then
  SPACK_NAME="\${ID/-/}"
else
  SPACK_NAME="\${ID/-/_}\${VERSION_ID/.*/}"
fi
export SPACK_ROOT=%{spack_dir}
export MODULEPATH=~/spack/modules/linux-\${SPACK_NAME}-\${CPU}:%{_prefix}/share/spack/modules/linux-\${SPACK_NAME}-\${CPU}:\${MODULEPATH}
# copy local configuration, if its not there
if [ ! -e ~/.spack/config.yaml ] ; then
  # test if user is in spack group by touching database
  if ! touch %{spack_dir}/.spack-db &> /dev/null ; then
    test -e ~/.spack || mkdir -p ~/.spack
    [ -e ~/.spack/config.yaml ] || \
     cp -r %{_sysconfdir}/skel/.spack/config.yaml ~/.spack/
    [ -e ~/.spack/modules.yaml ] || \
     cp -r %{_sysconfdir}/skel/.spack/modules.yaml ~/.spack/
  fi
fi
EOF
# Same for csh
cat > %{buildroot}/%{_sysconfdir}/profile.d/spack.csh <<EOF
# get ID
eval \`awk '/^ID=/ {sub("-","_"); printf("set %%s",\$0);}' /etc/os-release\`
# get VERSION_ID
eval \`awk '/^VERSION_ID=/ {sub("\\\\.[0-9]",""); printf("set %%s",\$0);}' /etc/os-release\`
if ( \$ID == "opensuse_tumbleweed" ) then
  eval \`awk '/^ID=/ {sub("-",""); printf("set %%s",\$0);}' /etc/os-release\`
  set SPACK_NAME=\$ID
else
  set SPACK_NAME="\${ID}\${VERSION_ID}"
endif
set SPACK_ROOT="%{spack_dir}"
set MODULEPATH="~/spack/modules/linux-\${SPACK_NAME}-\${CPU}:%{_prefix}/share/spack/modules/linux-\${SPACK_NAME}-\${CPU}:\${MODULEPATH}"
if ( ! -e ~/.spack/config.yaml )  then
  # test if user is in spack group by touching database
  touch %{spack_dir}/.spack-db  >& /dev/null
  if ( \$? == 1  ) then
    test -e ~/.spack || mkdir -p ~/.spack
    test -e ~/.spack/config.yaml  || \
     cp -r %{_sysconfdir}/skel/.spack/config.yaml ~/.spack/
    test -e ~/.spack/modules.yaml  || \
     cp -r %{_sysconfdir}/skel/.spack/modules.yaml ~/.spack/
  endif
endif

EOF
## Create modules.yaml file, so that hierarchy module files are created
#cat >  %{buildroot}%{spack_dir}/etc/spack/modules.yaml <<EOF
#modules:
#  enable:
#    - lmod
#  lmod:
#    core_compilers:
#      - 'gcc@GCC_FULL_VERSION'
#    projections:
#      all: '{compiler.name}-{compiler.version}/{name}/{version}'
#      ^mpi: '{compiler.name}-{compiler.version}/{^mpi.name}-{^mpi.version}/{name}/{version}'
#EOF
mkdir -p %{buildroot}%{_sysconfdir}/spack

# Fix link to not point into buildroot
rm -f %{buildroot}%{_localstatedir}/lib/spack/cache
ln -sf %{_localstatedir}/cache/spack %{buildroot}%{_localstatedir}/lib/spack/cache
# Remove problematic binaries which are removed upstream with
# 0889be20e0d9dcdf4346cdeaa0647285187375f3
rm -r %{buildroot}%{_localstatedir}/lib/spack/repos/builtin/packages/patchelf/test/

echo "g %{name} -" > system-group-%{name}.conf
%sysusers_generate_pre system-group-%{name}.conf %{name} system-group-%{name}.conf
install -D -m 644 system-group-%{name}.conf %{buildroot}%{_sysusersdir}/system-group-%{name}.conf

%fdupes %{buildroot}%{spack_dir}
%fdupes %{buildroot}%{_datarootdir}/spack
%fdupes %{buildroot}%{_localstatedir}/lib/spack
%{?_distconfdir:%fdupes %{buildroot}/%{_distconfdir}/spack}
%else
mkdir -p %{buildroot}%{_infodir}
mkdir -p %{buildroot}%{_mandir}/man1
cd lib/spack/docs/_build
cp man/spack.1.gz %{buildroot}%{_mandir}/man1/
cp -r texinfo/Spack.info.gz %{buildroot}%{_infodir}
[ -d texinfo/Spack-figures ] && cp -r texinfo/Spack-figures %{buildroot}%{_infodir}
%endif

%pre -f %{name}.pre

%post
# Replace /etc/spack/compilers.yaml
export GCC_VERSION=`gcc -dumpversion`
export GCC_FULL_VERSION=`gcc -dumpfullversion`

sed -i "s@GCC_FULL_VERSION@$GCC_FULL_VERSION@" %{spack_dir}/etc/spack/compilers.yaml
#sed -i "s@GCC_FULL_VERSION@$GCC_FULL_VERSION@" %{spack_dir}/etc/spack/modules.yaml
sed -i "s@GCC_VERSION@$GCC_VERSION@" %{spack_dir}/etc/spack/compilers.yaml
if [ -e /etc/os-release ] ;  then
  source /etc/os-release
  if [ "${ID}" == "opensuse-tumbleweed" ] ; then
    export SPACK_NAME="${ID/-/}"
  else
    export SPACK_NAME="${ID/-/_}${VERSION_ID/.*/}"
  fi
  sed -i "s@SUSE_VERSION@$SPACK_NAME@" %{spack_dir}/etc/spack/compilers.yaml
  sed -i "s@SUSE_VERSION@$SPACK_NAME@g" /etc/profile.d/spack.sh
fi
sed -i "s@HOSTTYPE@$HOSTTYPE@" %{spack_dir}/etc/spack/compilers.yaml
# find installed programms
/usr/lib/spack/run-find-external.sh
mkdir -p /opt/spack
chgrp spack /opt/spack
chmod 0775 /opt/spack

%triggerin -- %{?spack_trigger_recommended} %{?spack_trigger_packages} %{?spack_trigger_external}
/usr/lib/spack/run-find-external.sh

%triggerpostun -- %{?spack_trigger_recommended} %{?spack_trigger_packages} %{?spack_trigger_external}
/usr/lib/spack/run-find-external.sh

%if %{without doc}
%files
%license COPYRIGHT LICENSE-APACHE LICENSE-MIT
%doc CHANGELOG.md NOTICE README.md README.SUSE
%dir %{_sysconfdir}/spack/
%{_bindir}/*
%if 0%{?suse_version} <= 1500
%dir %{_prefix}/etc
%endif
%{_prefix}/etc/spack
%attr(0775, root, spack) %{_localstatedir}/lib/spack/junit-report
%attr(0775, root, spack) %{spack_dir}/opt
%attr(0775, root, spack) %{_localstatedir}/cache/spack
%attr(0775, root, spack) %{_datarootdir}/spack/modules
%{spack_dir}
%{_localstatedir}/cache/spack
%{_localstatedir}/lib/spack
%{_datarootdir}/spack
%config %{_sysconfdir}/profile.d/spack.sh
%ghost %config %{_sysconfdir}/spack/packages.yaml
%config %{_sysconfdir}/profile.d/spack.csh
%dir %{_sysconfdir}/skel/.spack
%config %{_sysconfdir}/skel/.spack/config.yaml
%config %{_sysconfdir}/skel/.spack/modules.yaml
# repos directory is installed in -recipes
%{_sysusersdir}/system-group-%{name}.conf
%exclude %{_localstatedir}/lib/spack/repos

%files recipes
%license COPYRIGHT LICENSE-APACHE LICENSE-MIT
%doc CHANGELOG.md NOTICE README.md
%{_localstatedir}/lib/spack/repos

%else

%post info
%install_info --info-dir=%{_infodir} --info-file="%{_infodir}/Spack.info.gz"

%preun info
%install_info_delete --info-dir=%{_infodir} --info-file="%{_infodir}/Spack.info.gz"

%files man
%{_mandir}/man1/*

%files info
%{_infodir}/*

%endif

%changelog
* Thu Apr  7 2022 eich@suse.com
- Fix: Fix-error-during-documentation-build-due-to-recursive-module-inclusion.patch
  This is needed to prevent an AttributeError during
  'import spack.environment as some_name'
  when building Sphinx documentation - due to an outdated
  Python on SLE.
  The original version caused errors:
  'NameError: name 'uenv' is not defined'
  when using 'spack env activate' et.al. (bsc#1198212).
* Wed Mar  2 2022 eich@suse.com
- Remove unneeded build dependency.
- Make dependencies of spack and spack-recipes symetrical.
* Thu Feb 10 2022 eich@suse.com
- Add openssl-devel, xz-devel and libzip-devel as recommends
  bsc#1195789.
* Wed Jan 12 2022 eich@suse.com
- Fix run-find-external.sh script: RPM macros are not expanded
  in external scripts.
  * Rename: run-find-external.sh to run-find-external.sh.in
- Fix list of recommended packages.
- Add support for container building using a SLE base container.
  * Add-support-for-container-building-using-a-SLE-base-container.patch
* Mon Jan 10 2022 cgoll@suse.com
- updated to spack 0.17.1 with following chnages:
  * Allow locks to work under high contention (#27846)
  * Improve errors messages from clingo (#27707 #27970)
  * Respect package permissions for sbang (#25764)
  * Fix --enable-locks behavior (#24675)
  * Fix log-format reporter ignoring install errors (#25961)
  * Fix overloaded argparse keys (#27379)
  * Allow style commands to run with targets other than "develop" (#27472)
  * Log lock messages to debug level, instead of verbose level (#27408)
  * Handle invalid unicode while logging (#21447)
  * spack audit: fix API calls to variants (#27713)
  * Provide meaningful message for empty environment installs (#28031)
  * Added opensuse leap containers to spack containerize (#27837)
  * Revert "patches: make re-applied patches idempotent" (#27625)
  * MANPATH can use system defaults (#21682)
  * Add "setdefault" subcommand to `spack module tcl` (#14686)
  * Regenerate views when specs already installed (#28113)
- removed leap-container.patch as incoperated upstream
* Tue Dec 14 2021 cgoll@suse.com
- fixed the configuration files /etc/skel/.spack/{config|modules}.yaml
  so that spack writes to $HOME if started as user
* Mon Dec 13 2021 cgoll@suse.com
- made objects.inv (Source5) to be static as the online version is changed
  dynamically
* Tue Dec  7 2021 cgoll@suse.com
- added leap-container.patch which adds leap15 as os to the
  spack containerize command.
* Mon Nov  8 2021 cgoll@suse.com
- updated to version 0.17.0
  (Upstream feature/bug references (<ID>) are relative to
  https://github.com/spack/spack/issues/<ID>).
  * New concretizer is now default
    The new concretizer introduced as an experimental feature in v0.16.0
    is now the default (#25502). The new concretizer is based on the
    clingo logic programming system,
    and it enables us to do much higher quality and faster dependency solving
    The old concretizer is still available via the concretizer: original
    setting, but it is deprecated and will be removed in v0.18.0.
  * Binary Bootstrapping
    To make it easier to use the new concretizer and binary packages,
    Spack now bootstraps clingo and GnuPG from public binaries. If it
    is not able to bootstrap them from binaries, it installs them from
    source code. With these changes, you should still be able to clone Spack
    and start using it almost immediately.
  * Reuse existing packages (experimental)
    The most wanted feature from our
    2020 user survey and
    the most wanted Spack feature of all time (#25310). spack install,
    spack spec, and spack concretize now have a --reuse option, which
    causes Spack to minimize the number of rebuilds it does. The --reuse
    option will try to find existing installations and binary packages locally
    and in registered mirrors, and will prefer to use them over building new
    versions. This will allow users to build from source far less than in
    prior versions of Spack. This feature will continue to be improved, with
    configuration options and better CLI expected in v0.17.1. It will become
    the default concretization mode in v0.18.0.
  * Better error messages
    We have improved the error messages generated by the new concretizer by
    using unsatisfiable cores. Spack will now print a summary of the types
    of constraints that were violated to make a spec unsatisfiable (#26719).
  * Conditional variants
    Variants can now have a when="<spec>" clause, allowing them to be
    conditional based on the version or other attributes of a package (#24858).
  * Git commit versions
    In an environment and on the command-line, you can now provide a full,
    40-character git commit as a version for any package with a top-level
    git URL. e.g., spack install hdf5@45bb27f58240a8da7ebb4efc821a1a964d7712a8.
    Spack will compare the commit to tags in the git repository to understand
    what versions it is ahead of or behind.
  * Override local config and cache directories
    You can now set SPACK_DISABLE_LOCAL_CONFIG to disable the ~/.spack and
    /etc/spack configuration scopes. SPACK_USER_CACHE_PATH allows you to
    move caches out of ~/.spack, as well (#27022, #26735). This addresses
    common problems where users could not isolate CI environments from local
    configuration.
  * Improvements to Spack Containerize
    For added reproducibility, you can now pin the Spack version used by
    spack containerize (#21910). The container build will only build
    with the Spack version pinned at build recipe creation instead of the
    latest Spack version.
  * New commands for dealing with tags
    The spack tags command allows you to list tags on packages (#26136), and you
    can list tests and filter tags with spack test list (#26842).
  * Copy and relocate environment views as stand-alone installations (#24832)
  * spack diff command can diff two installed specs (#22283, #25169)
  * spack -c <config> can set one-off config parameters on CLI (#22251)
  * spack load --list is an alias for spack find --loaded (#27184)
  * spack gpg can export private key with --secret (#22557)
  * spack style automatically bootstraps dependencies (#24819)
  * spack style --fix automatically invokes isort (#24071)
  * build dependencies can be installed from build caches with --include-build-deps (#19955)
  * spack audit command for checking package constraints (#23053)
  * spack can now fetch from CVS repositories (yep, really) (#23212)
  * spack monitor lets you upload analysis about installations to a
  * spack monitor server (#23804, #24321, #23777, #25928))
  * spack python --path shows which python Spack is using (#22006)
  * spack env activate --temp can create temporary environments (#25388)
  * --preferred and --latest options for spack checksum (#25830)
  * SPACK_PYTHON environment variable sets which python spack uses (#21222)
  * SPACK_SKIP_MODULES lets you source setup-env.sh faster if you don't need modules (#24545)
- removed following patches as incomperated upstream:
  * added-dockerfile-for-opensuse-leap-15.patch
- removed as not needed any more:
  * basic-exclude-pattern-for-external-find.patch
  * Fix-documentation-so-that-parser-doesn-t-stumble.patch
- updated patches:
  * Adapt-shell-scripts-that-set-up-the-environment-for-different-shells.patch
  * added-target-and-os-calls-to-output-of-spack-spec-co.patch
  * Fix-error-during-documentation-build-due-to-recursive-module-inclusion.patch
  * fix-tumbleweed-naming.patch
  * Make-spack-paths-compliant-to-distro-installation.patch
- added:
  * Fix-Spinx-configuration-to-avoid-throwing-errors.patch
  * Set-modules-default-to-lmod.patch
- updated requires to actual sphinx version, so that the documentation
  builds
- Included source:
  objects.inv
* Fri Oct 15 2021 eich@suse.com
- Fix sysuser file name.
* Fri Oct  1 2021 eich@suse.com
- Utilize sysuser infrastructure to set group spack.
* Wed Sep 29 2021 aginies@suse.com
- update to version 0.16.3 (JSC#SLE-22137):
  * clang/llvm: fix version detection
  * Fix use of quotes in Python build system
  * Ensure all roots of an installed environment are marked explicit in db
  * Fix fetching for Python 3.8 and 3.9
  * locks: only open lockfiles once instead of for every lock held
* Fri Aug  6 2021 cgoll@suse.com
- added tar and make as requirement
* Wed Jul  7 2021 cgoll@suse.com
- added README-oo-wiki which is the raw version of the opensuse wiki
* Tue Jul  6 2021 eich@suse.com
- Fix patch
  Fix-error-during-documentation-build-due-to-recursive-module-inclusion.patch
  to actually work correctly.
  The updated version makes sure modules are not called recursively even
  if modules are loaded in an out-of-order fashion from python-Sphinx.
- Remove duplicates in spec file.
* Wed Jun  2 2021 aginies@suse.com
- fix typo to export prefix in patch (bsc#1191395):
  Adapt-shell-scripts-that-set-up-the-environment-for-different-shells.patch
* Tue May 25 2021 cgoll@suse.com
- update to version 0.16.1
  * Major performance improvement for spack load and other commands.
  * spack fetch is now environment-aware. (#19166)
  * Numerous fixes for the new, clingo-based concretizer.
  * Supoprt for automatically bootstrapping clingo from source.
  * Python 3.10 support: collections.abc
  * Fix import issues by using __import__ instead of Spack package import.
  * Bugfixes and --source-dir argument for spack location.
  * Better support for externals in shared prefixes.
  * spack build-env now prefers specs defined in the active environment.
  * Remove erroneous warnings about quotes in from_sourcing_files.
  * Fix clearing cache of InternalConfigScope.
  * Bugfix for active when pkg is already active error.
  * Make SingleFileScope able to repopulate the cache after clearing it.
  * Channelflow: Fix the package.
  * More descriptive error message for bugs in package.py
  * Use package-supplied autogen.sh
  * Respect -k/verify-ssl-false in _existing_url method.
* Mon May  3 2021 eich@suse.com
- Add gcc-c++ to the required packages (bsc#1185519).
- Add alternative c++ & fortran compilers to the triggers list.
* Tue Mar 30 2021 cgoll@suse.com
- added run-find-external.sh which calls the command in post
  `spack external find` as nobody and not as root
* Tue Mar 23 2021 cgoll@suse.com
- added libbz2-devel as dependency as spack requires this, as soon
  as the bzip2 binary is found and removed warning for this
  corner case in rpmlinrc
* Fri Mar 19 2021 cgoll@suse.com
- set the right MODULEPATH in /etc/profile.d/spack.[cs]h
* Fri Feb 26 2021 eich@suse.com
- Remove BuildRequires for patterns-base-basesystem and
  distribution-release.
* Fri Feb 26 2021 cgoll@suse.com
- update to version 0.16.1
  * intel-oneapi support through new packages
  * HIP/ROCm support (#19715, #20095)
  * concretization enhancements
  * environment install reporting fix (#20004)
  * avoid import in ABI compatibility info (#20236)
  * restore ability of dev-build to skip patches (#20351)
  * spack find -d spec grouping (#20028)
  * spack smoke test support (#19987, #20298)
  * abstract spec comparisons (#20341)
  * performance improvements for binary relocation (#19690, #20768)
  * additional sanity checks for variants in builtin packages (#20373)
  * do not pollute auto-generated configuration files with empty lists or
    dicts
- added file: basic-exclude-pattern-for-external-find.patch
  * adds the functionality to exclude binaries for external search
    so that the call 'installdbgsymbols' can be prohibited as this
    leads to an endless loop when drkonqui is installed
* Thu Feb  4 2021 eich@suse.com
- Add
  * Fix-documentation-so-that-parser-doesn-t-stumble.patch:
  * Fix-error-during-documentation-build-due-to-recursive-module-inclusion.patch
    Fix documentation building.
- Fix texinfo file installation.
* Fri Dec 11 2020 cgoll@suse.com
- added patch for more reproduceable output for the doc package
  * added file: added-target-and-os-calls-to-output-of-spack-spec-co.patch
* Tue Dec  8 2020 cgoll@suse.com
- added test for /etc/spack/no_rpm_trigger
* Wed Dec  2 2020 cgoll@suse.com
- added %%triggerin and %%triggerpostun for the packages which
  can be detected by spack
* Wed Nov 25 2020 cgoll@suse.com
- updated to 0.16.0
- added find for external packages
- added dockerfile for leap
  * added patchfile added-dockerfile-for-opensuse-leap-15.patch
* Tue Nov 24 2020 eich@suse.com
- Add documentation (man and info pages, pdf doesn't build
  currently).
  * Do not ship documentation sources.
- Do not distribute Dockerfiles and other container related
  material, yet. This needs to be fixed so that the samples
  work with SUSE.
- Fully integrate spack into SUSE directory structure, fix
  paths where required.
  * Fix setup scripts to work correctly in above environment.
* Mon Nov 16 2020 cgoll@suse.com
- added profile file for csh
- enabled projections
- updated README.SUSE
* Wed Nov 11 2020 cgoll@suse.com
- added patches to be more on the traditional file system hierarchy
  and avoid explicit version in tumbleweed.
  * added file Make-spack-paths-compliant-to-distro-installation.patch
  * added file fix-tumbleweed-naming.patch
* Fri Sep 11 2020 aguerrero@suse.com
- Initial release. Version 0.15.4
  * Make-spack-paths-compliant-to-distro-installation.patch
    Make spack paths compliant to distro installation.
